==> pmml-model-gwt-1.5.12-sources.jar: org/dmg/pmml/naive_bayes/TargetValueStats.java <==

package org.dmg.pmml.naive_bayes;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.Property;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "TargetValueStats", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "targetValueStats"
})
@Added((org.dmg.pmml.Version.PMML_4_2))
@JsonRootName("TargetValueStats")
@JsonPropertyOrder({
    "extensions",
    "targetValueStats"
})
public class TargetValueStats
    extends org.dmg.pmml.PMMLObject
    implements Iterable<TargetValueStat> , HasExtensions<TargetValueStats>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "TargetValueStat", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("TargetValueStat")
    private List<TargetValueStat> targetValueStats;
    private final static long serialVersionUID = 67371267L;

    public TargetValueStats() {
    }

    @ValueConstructor
    public TargetValueStats(
        @Property("targetValueStats")
        List<TargetValueStat> targetValueStats) {
        this.targetValueStats = targetValueStats;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public TargetValueStats addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public Iterator<TargetValueStat> iterator() {
        return getTargetValueStats().iterator();
    }

    public boolean hasTargetValueStats() {
        return ((this.targetValueStats!= null)&&(this.targetValueStats.size()> 0));
    }

    public List<TargetValueStat> getTargetValueStats() {
        if (targetValueStats == null) {
            targetValueStats = new ArrayList<TargetValueStat>();
        }
        return this.targetValueStats;
    }

    public TargetValueStats addTargetValueStats(TargetValueStat... targetValueStats) {
        getTargetValueStats().addAll(Arrays.asList(targetValueStats));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasTargetValueStats()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTargetValueStats());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.2-sources.jar: org/dmg/pmml/naive_bayes/TargetValueStats.java <==

package org.dmg.pmml.naive_bayes;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.MissingElementException;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.Property;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "TargetValueStats", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "targetValueStats"
})
@Added((org.dmg.pmml.Version.PMML_4_2))
@JsonRootName("TargetValueStats")
@JsonPropertyOrder({
    "extensions",
    "targetValueStats"
})
public class TargetValueStats
    extends org.dmg.pmml.PMMLObject
    implements Iterable<TargetValueStat> , HasExtensions<TargetValueStats>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "TargetValueStat", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("TargetValueStat")
    private List<TargetValueStat> targetValueStats;
    private final static long serialVersionUID = 67371269L;

    public TargetValueStats() {
    }

    @ValueConstructor
    public TargetValueStats(
        @Property("targetValueStats")
        List<TargetValueStat> targetValueStats) {
        this.targetValueStats = targetValueStats;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public TargetValueStats addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public Iterator<TargetValueStat> iterator() {
        return requireTargetValueStats().iterator();
    }

    public boolean hasTargetValueStats() {
        return ((this.targetValueStats!= null)&&(!this.targetValueStats.isEmpty()));
    }

    public List<TargetValueStat> requireTargetValueStats() {
        if ((this.targetValueStats == null)||this.targetValueStats.isEmpty()) {
            throw new MissingElementException(this, PMMLElements.TARGETVALUESTATS_TARGETVALUESTATS);
        }
        return this.targetValueStats;
    }

    public List<TargetValueStat> getTargetValueStats() {
        if (targetValueStats == null) {
            targetValueStats = new ArrayList<TargetValueStat>();
        }
        return this.targetValueStats;
    }

    public TargetValueStats addTargetValueStats(TargetValueStat... targetValueStats) {
        getTargetValueStats().addAll(Arrays.asList(targetValueStats));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasTargetValueStats()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTargetValueStats());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
